three_js_text library

Classes

ExtrudeGeometry
Creates extruded geometry from a path shape.
ExtrudeGeometryOptions
Font
FontLoader
Class for loading a font in JSON format. Returns a font, which is an array of Shapes representing the font. This uses the FileLoader internally for loading files.
TextGeometry
A class for generating text as a single geometry. It is constructed by providing a string of text, and a set of parameters consisting of a loaded font and settings for the geometry's parent ExtrudeGeometry. See the FontLoader page for additional details.
TextGeometryOptions
TTFFont
TTFLoader
Requires opentype.js to be included in the project. Loads TTF files and converts them into typeface JSON that can be used directly to create THREE.Font objects.
TYPRFont
TYPRLoader
Requires opentype.js to be included in the project. Loads TTF files and converts them into typeface JSON that can be used directly to create Font objects.
WorldUVGenerator

Functions

toJSON2(dynamic shapes, Map<String, dynamic>? options, dynamic data) Map<String, dynamic>