BinT class

Constructors

BinT()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

buff ↔ ByteData
getter/setter pair
int16 ↔ Int16List
getter/setter pair
int32 ↔ Int32List
getter/setter pair
int8 ↔ Int8List
getter/setter pair
uint16 ↔ Uint16List
getter/setter pair
uint32 ↔ Uint32List
getter/setter pair
uint8 ↔ Uint8List
getter/setter pair