TyprBin class

Constructors

TyprBin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

readASCII(List<int> buff, int p, dynamic l) → String
readASCIIArray(List<int> buff, int p, int l) → List<String>
readBytes(List<int> buff, int p, int l) → List<int>
readF2dot14(List<int> data, int o) → num
readFixed(List<int> data, int o) → num
readInt(List<int> buff, int p) → int
readInt8(List<int> buff, int p) → int
readShort(List<int> buff, int p) → int
readUint(List<int> buff, int p) → int
readUint64(dynamic buff, dynamic p) → dynamic
readUnicode(List<int> buff, int p, int l) → String
readUshort(List<int> buff, int p) → int
readUshorts(List<int> buff, int p, int len) → List<int>
readUTF8(List<int> buff, int p, int l) → String