Typr_CMAP class

Constructors

Typr_CMAP()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

parse(Uint8List buffer, int offset, int length) → Map<String, dynamic>
parse0(Uint8List data, int offset) → Map<String, dynamic>
parse12(Uint8List data, int offset) → Map<String, dynamic>
parse4(Uint8List data, int offset) → Map<String, dynamic>
parse6(Uint8List data, int offset) → Map<String, dynamic>